aboutsummaryrefslogtreecommitdiffstats
path: root/home
diff options
context:
space:
mode:
authorRangi <remy.oukaour+rangi42@gmail.com>2021-05-06 23:04:00 -0400
committerRangi <remy.oukaour+rangi42@gmail.com>2021-05-06 23:04:00 -0400
commitc8626595b447358e568a8d23738b832f50351f77 (patch)
tree6dc195079646a3921eac85c3f653459f09983df2 /home
parentMerge pull request #321 from SatoMew/master (diff)
downloadpokeyellow-c8626595b447358e568a8d23738b832f50351f77.tar.gz
pokeyellow-c8626595b447358e568a8d23738b832f50351f77.tar.xz
pokeyellow-c8626595b447358e568a8d23738b832f50351f77.zip
Use BANK("Pics #") for Pokémon and trainer pics
Diffstat (limited to 'home')
-rw-r--r--home/pics.asm26
1 files changed, 13 insertions, 13 deletions
diff --git a/home/pics.asm b/home/pics.asm
index ef668620..3bce1532 100644
--- a/home/pics.asm
+++ b/home/pics.asm
@@ -9,14 +9,14 @@ UncompressMonSprite::
ld a, [hl]
ld [wSpriteInputPtr+1], a
; define (by index number) the bank that a pokemon's image is in
-; index = Mew, bank 1
-; index = Kabutops fossil, bank $B
-; index < $1F, bank 9
-; $1F ≤ index < $4A, bank $A
-; $4A ≤ index < $74, bank $B
-; $74 ≤ index < $99, bank $C
-; $99 ≤ index, bank $D
- ld a, [wcf91] ; XXX name for this ram location
+; index = MEW: bank $1
+; index = FOSSIL_KABUTOPS: bank $B
+; index < $1F: bank $9 ("Pics 1")
+; $1F ≤ index < $4A: bank $A ("Pics 2")
+; $4A ≤ index < $74: bank $B ("Pics 3")
+; $74 ≤ index < $99: bank $C ("Pics 4")
+; $99 ≤ index: bank $D ("Pics 5")
+ ld a, [wcf91]
ld b, a
cp MEW
ld a, BANK(MewPicFront)
@@ -27,21 +27,21 @@ UncompressMonSprite::
jr z, .GotBank
ld a, b
cp TANGELA + 1
- ld a, BANK(TangelaPicFront)
+ ld a, BANK("Pics 1")
jr c, .GotBank
ld a, b
cp MOLTRES + 1
- ld a, BANK(MoltresPicFront)
+ ld a, BANK("Pics 2")
jr c, .GotBank
ld a, b
cp BEEDRILL + 2
- ld a, BANK(BeedrillPicFront)
+ ld a, BANK("Pics 3")
jr c, .GotBank
ld a, b
cp STARMIE + 1
- ld a, BANK(StarmiePicFront)
+ ld a, BANK("Pics 4")
jr c, .GotBank
- ld a, BANK(VictreebelPicFront)
+ ld a, BANK("Pics 5")
.GotBank
jp UncompressSpriteData